/* See LICENSE file for copyright and license details. */

#include <X11/XF86keysym.h>
#include <X11/XKBlib.h>

/* Function to toggle between the two layouts */
/*
void toggle_keyboard_layout(const Arg* arg) {
    XkbStateRec state;
    if (XkbGetState(dpy, XkbUseCoreKbd, &state) != Success) {
        fprintf(stderr, "Failed to get keyboard state\n");
        return;
    }
    unsigned int newGroup = (state.group == 0) ? 1 : 0;
    if (XkbLockGroup(dpy, XkbUseCoreKbd, newGroup) != True) {
        fprintf(stderr, "Failed to toggle keyboard layout\n");
    }
}
*/

// Normal config.def.h continues. I just added some of my own functions

/* appearance */
static const unsigned int borderpx  = 3;        /* border pixel of windows */
static const unsigned int gappx     = 2;        /* gap pixel between windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "monospace:size=10" };
static const char dmenufont[]       = "monospace:size=10";
static const char *colors[][3]      = {
	/*               fg         bg         border   */
	[SchemeNorm] = { "#eeeeee", "#222222", "#111111" },
	[SchemeSel]  = { "#000000", "#e0b000",  "#e0b000"  },
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title       tags mask     isfloating   monitor */
	{ "Gimp",     NULL,       NULL,       0,            1,           -1 },
	//{ "Firefox",  NULL,       NULL,       1 << 8,       0,           -1 },
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
//static const char *dmenucmd_old[] = { "dmenu_run", "-m", dmenumon, "-fn", dmenufont, "-nb", col_gray1, "-nf", col_gray3, "-sb", col_cyan, "-sf", col_gray4, NULL };
static const char *termcmd[]  = { "st", NULL };
static const char *dmenucmd[] = {"sh", "-c", "${HOME}/.config/suckless_desktop/win_r_out/invoke.sh", NULL};
static const char* termtmuxzshcmd[] = {"st", "-e", "tmux", "new-session", "zsh", NULL};
static const char* flameshotcmd[] = {"flameshot", "gui", NULL};
static const char* pa_mute[] = {"pactl", "set-sink-mute", "@DEFAULT_SINK@", "toggle", NULL};
static const char* pa_lower[] = {"pactl", "set-sink-volume", "@DEFAULT_SINK@", "-5%", NULL};
static const char* pa_raise[] = {"pactl", "set-sink-volume", "@DEFAULT_SINK@", "+5%", NULL};
static const char* slockcmd[] = {"slock", NULL};

static const Key keys[] = {
	/* modifier                     key        function        argument */
    { 0,                   XK_Print,                spawn,          {.v = flameshotcmd } },
    { 0,            XF86XK_AudioMute,               spawn,          {.v = pa_mute } }, 
    { 0,       XF86XK_AudioLowerVolume,             spawn,          {.v = pa_lower } }, 
    { 0,       XF86XK_AudioRaiseVolume,             spawn,          {.v = pa_raise } },
    { MODKEY,                       XK_F1,          spawn,          {.v = pa_mute } },
    { MODKEY,                       XK_F2,          spawn,          {.v = pa_lower } },
    { MODKEY,                       XK_F3,          spawn,          {.v = pa_raise } },
    { MODKEY|ShiftMask,             XK_l,           spawn,          {.v = slockcmd } },
    { MODKEY,                       XK_r,           spawn,          {.v = dmenucmd } },
	{ MODKEY|ControlMask,           XK_s,           spawn,          {.v = termcmd } },
	{ MODKEY,                       XK_s,           spawn,          {.v = termtmuxzshcmd } },
	{ MODKEY,                       XK_b,           togglebar,      {0} },
	{ MODKEY,                       XK_k,           focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_l,           focusstack,     {.i = -1 } },
	{ MODKEY,                       XK_i,           incnmaster,     {.i = +1 } },
	{ MODKEY,                       XK_d,           incnmaster,     {.i = -1 } },
	{ MODKEY|ControlMask,           XK_j,           setmfact,       {.f = -0.05} },
	{ MODKEY|ControlMask,           XK_semicolon,   setmfact,       {.f = +0.05} },
	{ MODKEY,                       XK_Return,      zoom,           {0} },
	{ MODKEY,                       XK_Tab,         view,           {0} },
	{ MODKEY,                       XK_F4,          killclient,     {0} },
	{ MODKEY,                       XK_t,           setlayout,      {.v = &layouts[0]} },
	{ MODKEY,                       XK_f,           setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_m,           setlayout,      {.v = &layouts[2]} },
	// { MODKEY|ShiftMask,                       XK_space,  setlayout,      {0} },
	{ MODKEY|ControlMask,           XK_space,       togglefloating, {0} },
	{ MODKEY,                       XK_0,           view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,           tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_j,           focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_semicolon,   focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_j,           tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_semicolon,   tagmon,         {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_q,           quit,           {0} },
	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	TAGKEYS(                        XK_5,                      4)
	TAGKEYS(                        XK_6,                      5)
	TAGKEYS(                        XK_7,                      6)
	TAGKEYS(                        XK_8,                      7)
	TAGKEYS(                        XK_9,                      8)
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

